Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMorris Jobke <hey@morrisjobke.de>2018-11-12 19:43:56 +0300
committerGitHub <noreply@github.com>2018-11-12 19:43:56 +0300
commitfd8eeccb15e1219a2d18fc421e741c315737c55e (patch)
tree55b56592cf40ab4fcc605e45a95d13d79806eb91 /lib/public
parent9e1ec0cf46055dbf08a139124d292eb38b8aebd2 (diff)
parentbb352fb667e87ea0829f1da5f9e85c34bdefe9fa (diff)
Merge pull request #11942 from nextcloud/techdebt/noid/use-count-function
Use the defined func()->count() instead of manual counting
Diffstat (limited to 'lib/public')
-rw-r--r--lib/public/DB/QueryBuilder/IFunctionBuilder.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/public/DB/QueryBuilder/IFunctionBuilder.php b/lib/public/DB/QueryBuilder/IFunctionBuilder.php
index 51b639028ce..1e17290f145 100644
--- a/lib/public/DB/QueryBuilder/IFunctionBuilder.php
+++ b/lib/public/DB/QueryBuilder/IFunctionBuilder.php
@@ -98,10 +98,11 @@ interface IFunctionBuilder {
public function subtract($x, $y);
/**
* @param mixed $input The input to be counted
*
* @return IQueryFunction
* @since 14.0.0
*/
- public function count($input);
+ public function count($count, $alias = '');
}
@@ -98,10 +98,11 @@ interface IFunctionBuilder {
public function subtract($x, $y);
/**
- * @param mixed $input The input to be counted
+ * @param mixed $count The input to be counted
+ * @param string $alias Alias for the counter
*
* @return IQueryFunction